==> haskell-commutative-semigroups-0.1.0.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commutative-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commutative-semigroups
version:              0.1.0.2
visibility:           public
id:                   commutative-semigroups-0.1.0.2-IutkYzDs43W8HtiWkPtj05
key:                  commutative-semigroups-0.1.0.2-IutkYzDs43W8HtiWkPtj05
license:              BSD-3-Clause
copyright:
    Copyright (C) 2013 Nathan van Doorn, 2021–2022 Obsidian Systems LLC

maintainer:           maintainer@obsidian.systems
author:               Nathan "Taneb" van Doorn
synopsis:             Commutative semigroups
description:
    A commutative semigroup is a semigroup where the order of arguments to mappend does not matter.

category:             Algebra, Data, Math
abi:                  55c0889f8cb75b537d7b5952a14a789f
exposed:              True
exposed-modules:
    Data.Semigroup.Commutative Numeric.Product.Commutative

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/commutative-semigroups-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/commutative-semigroups-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commutative-semigroups
hs-libraries:         HScommutative-semigroups-0.1.0.2-IutkYzDs43W8HtiWkPtj05
depends:              base-4.16.4.0 containers-0.6.5.1
haddock-interfaces:
    /usr/share/doc/haskell-commutative-semigroups/html/commutative-semigroups.haddock

haddock-html:         /usr/share/doc/haskell-commutative-semigroups/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commutative-semigroups-0.2.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commutative-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commutative-semigroups
version:              0.2.0.1
visibility:           public
id:                   commutative-semigroups-0.2.0.1-EH8LNaj5YwqAbhqQrh5UPi
key:                  commutative-semigroups-0.2.0.1-EH8LNaj5YwqAbhqQrh5UPi
license:              BSD-3-Clause
copyright:
    Copyright (C) 2013 Nathan van Doorn, 2021–2022 Obsidian Systems LLC

maintainer:           maintainer@obsidian.systems
author:               Nathan "Taneb" van Doorn
synopsis:             Commutative semigroups
description:
    A commutative semigroup is a semigroup where the order of arguments to mappend does not matter.

category:             Algebra, Data, Math
abi:                  74e302217a9ee9d645b093ae94060223
exposed:              True
exposed-modules:
    Data.Semigroup.Commutative Numeric.Product.Commutative

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/commutative-semigroups-0.2.0.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/commutative-semigroups-0.2.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commutative-semigroups
hs-libraries:         HScommutative-semigroups-0.2.0.1-EH8LNaj5YwqAbhqQrh5UPi
depends:              base-4.16.4.0 containers-0.6.5.1
haddock-interfaces:
    /usr/share/doc/haskell-commutative-semigroups/html/commutative-semigroups.haddock

haddock-html:         /usr/share/doc/haskell-commutative-semigroups/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
